import { Injectable } from "@angular/core";
import { Actions, Effect, ofType } from "@ngrx/effects";
import { Store } from "@ngrx/store";
import { catchError, map, switchMap } from "rxjs/operators";

import { State } from "../../../share/store";
import { Bar } from "../../models/bar.model";
import { BarsService } from "../../services/bars.service";
import { BarsActionsTypes, FetchBarsSuccess } from "../actions/bars.actions";

@Injectable()
export class BarsEffect {
	constructor(
		private actions$: Actions,
		private store: Store<State>,
		private barssService: BarsService
	) {}

	@Effect()
	FetchBars$ = this.actions$.pipe(
		ofType(BarsActionsTypes.FETCH_BARS),
		switchMap(() => {
			return this.barssService.getAllBars();
		}),
		map((bars: Bar[]) => {
			return new FetchBarsSuccess(bars);
		})
	);
}